@@ -1,8 +1,9 @@
 from typing import Any, cast, Dict, Optional, Union
 
 from gitlab import exceptions as exc
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import GetWithoutIdMixin, SaveMixin, UpdateMixin
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "ApplicationAppearance",
@@ -58,7 +59,5 @@ class ApplicationAppearanceManager(GetWithoutIdMixin, UpdateMixin, RESTManager):
         data = new_data.copy()
         return super().update(id, data, **kwargs)
 
-    def get(
-        self, id: Optional[Union[int, str]] = None, **kwargs: Any
-    ) -> Optional[ApplicationAppearance]:
-        return cast(Optional[ApplicationAppearance], super().get(id=id, **kwargs))
+    def get(self, **kwargs: Any) -> ApplicationAppearance:
+        return cast(ApplicationAppearance, super().get(**kwargs))
