@@ -1,6 +1,15 @@
+from typing import Any, cast, Union
+
 from gitlab import types
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
-from gitlab.mixins import CreateMixin, DeleteMixin, ListMixin, ObjectDeleteMixin
+from gitlab.base import RESTManager, RESTObject
+from gitlab.mixins import (
+    CreateMixin,
+    DeleteMixin,
+    ListMixin,
+    ObjectDeleteMixin,
+    RetrieveMixin,
+)
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "DeployToken",
@@ -25,7 +34,7 @@ class GroupDeployToken(ObjectDeleteMixin, RESTObject):
     pass
 
 
-class GroupDeployTokenManager(ListMixin, CreateMixin, DeleteMixin, RESTManager):
+class GroupDeployTokenManager(RetrieveMixin, CreateMixin, DeleteMixin, RESTManager):
     _path = "/groups/{group_id}/deploy_tokens"
     _from_parent_attrs = {"group_id": "id"}
     _obj_cls = GroupDeployToken
@@ -41,12 +50,17 @@ class GroupDeployTokenManager(ListMixin, CreateMixin, DeleteMixin, RESTManager):
     )
     _types = {"scopes": types.CommaSeparatedListAttribute}
 
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> GroupDeployToken:
+        return cast(GroupDeployToken, super().get(id=id, lazy=lazy, **kwargs))
+
 
 class ProjectDeployToken(ObjectDeleteMixin, RESTObject):
     pass
 
 
-class ProjectDeployTokenManager(ListMixin, CreateMixin, DeleteMixin, RESTManager):
+class ProjectDeployTokenManager(RetrieveMixin, CreateMixin, DeleteMixin, RESTManager):
     _path = "/projects/{project_id}/deploy_tokens"
     _from_parent_attrs = {"project_id": "id"}
     _obj_cls = ProjectDeployToken
@@ -61,3 +75,8 @@ class ProjectDeployTokenManager(ListMixin, CreateMixin, DeleteMixin, RESTManager
         ),
     )
     _types = {"scopes": types.CommaSeparatedListAttribute}
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectDeployToken:
+        return cast(ProjectDeployToken, super().get(id=id, lazy=lazy, **kwargs))
