@@ -1,7 +1,7 @@
-from typing import Any, cast, Dict, List, Optional, TYPE_CHECKING, Union
+from typing import Any, cast, Dict, List, Optional, TYPE_CHECKING
 
 from gitlab import exceptions as exc
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     DeleteMixin,
@@ -11,6 +11,7 @@ from gitlab.mixins import (
     SaveMixin,
     UpdateMixin,
 )
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "ProjectApproval",
@@ -45,10 +46,8 @@ class ProjectApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTManager):
     )
     _update_uses_post = True
 
-    def get(
-        self, id: Optional[Union[int, str]] = None, **kwargs: Any
-    ) -> Optional[ProjectApproval]:
-        return cast(Optional[ProjectApproval], super().get(id=id, **kwargs))
+    def get(self, **kwargs: Any) -> ProjectApproval:
+        return cast(ProjectApproval, super().get(**kwargs))
 
     @exc.on_http_error(exc.GitlabUpdateError)
     def set_approvers(
@@ -110,10 +109,8 @@ class ProjectMergeRequestApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTMan
     _update_attrs = RequiredOptional(required=("approvals_required",))
     _update_uses_post = True
 
-    def get(
-        self, id: Optional[Union[int, str]] = None, **kwargs: Any
-    ) -> Optional[ProjectMergeRequestApproval]:
-        return cast(Optional[ProjectMergeRequestApproval], super().get(id=id, **kwargs))
+    def get(self, **kwargs: Any) -> ProjectMergeRequestApproval:
+        return cast(ProjectMergeRequestApproval, super().get(**kwargs))
 
     @exc.on_http_error(exc.GitlabUpdateError)
     def set_approvers(
@@ -160,13 +157,14 @@ class ProjectMergeRequestApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTMan
                 ar.save()
                 return ar
         # if there was no rule matching the rule name, create a new one
-        return approval_rules.create(data=data)
+        return approval_rules.create(data=data, **kwargs)
 
 
 class ProjectMergeRequestApprovalRule(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _id_attr = "approval_rule_id"
-    _repr_attr = "approval_rule"
+    _repr_attr = "name"
     id: int
+    approval_rule_id: int
+    merge_request_iid: int
 
     @exc.on_http_error(exc.GitlabUpdateError)
     def save(self, **kwargs: Any) -> None:
@@ -252,9 +250,5 @@ class ProjectMergeRequestApprovalStateManager(GetWithoutIdMixin, RESTManager):
     _obj_cls = ProjectMergeRequestApprovalState
     _from_parent_attrs = {"project_id": "project_id", "mr_iid": "iid"}
 
-    def get(
-        self, id: Optional[Union[int, str]] = None, **kwargs: Any
-    ) -> Optional[ProjectMergeRequestApprovalState]:
-        return cast(
-            Optional[ProjectMergeRequestApprovalState], super().get(id=id, **kwargs)
-        )
+    def get(self, **kwargs: Any) -> ProjectMergeRequestApprovalState:
+        return cast(ProjectMergeRequestApprovalState, super().get(**kwargs))
