@@ -1,11 +1,21 @@
-from typing import Any, Callable, cast, Dict, List, Optional, TYPE_CHECKING, Union
+from typing import (
+    Any,
+    Callable,
+    cast,
+    Dict,
+    Iterator,
+    List,
+    Optional,
+    TYPE_CHECKING,
+    Union,
+)
 
 import requests
 
 from gitlab import cli, client
 from gitlab import exceptions as exc
 from gitlab import types, utils
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     CRUDMixin,
@@ -16,6 +26,7 @@ from gitlab.mixins import (
     SaveMixin,
     UpdateMixin,
 )
+from gitlab.types import RequiredOptional
 
 from .access_requests import ProjectAccessRequestManager  # noqa: F401
 from .artifacts import ProjectArtifactManager  # noqa: F401
@@ -30,7 +41,10 @@ from .custom_attributes import ProjectCustomAttributeManager  # noqa: F401
 from .deploy_keys import ProjectKeyManager  # noqa: F401
 from .deploy_tokens import ProjectDeployTokenManager  # noqa: F401
 from .deployments import ProjectDeploymentManager  # noqa: F401
-from .environments import ProjectEnvironmentManager  # noqa: F401
+from .environments import (  # noqa: F401
+    ProjectEnvironmentManager,
+    ProjectProtectedEnvironmentManager,
+)
 from .events import ProjectEventManager  # noqa: F401
 from .export_import import ProjectExportManager, ProjectImportManager  # noqa: F401
 from .files import ProjectFileManager  # noqa: F401
@@ -174,6 +188,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     pagesdomains: ProjectPagesDomainManager
     pipelines: ProjectPipelineManager
     pipelineschedules: ProjectPipelineScheduleManager
+    protected_environments: ProjectProtectedEnvironmentManager
     protectedbranches: ProjectProtectedBranchManager
     protectedtags: ProjectProtectedTagManager
     pushrules: ProjectPushRulesManager
@@ -449,7 +464,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
 
         url = f"/projects/{self.encoded_id}/uploads"
         file_info = {"file": (filename, filedata)}
-        data = self.manager.gitlab.http_post(url, files=file_info)
+        data = self.manager.gitlab.http_post(url, files=file_info, **kwargs)
 
         if TYPE_CHECKING:
             assert isinstance(data, dict)
@@ -463,8 +478,10 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         streamed: bool = False,
         action: Optional[Callable] = None,
         chunk_size: int = 1024,
+        *,
+        iterator: bool = False,
         **kwargs: Any,
-    ) -> Optional[bytes]:
+    ) -> Optional[Union[bytes, Iterator[Any]]]:
         """Return a snapshot of the repository.
 
         Args:
@@ -472,6 +489,8 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             streamed: If True the data will be processed by chunks of
                 `chunk_size` and each chunk is passed to `action` for
                 treatment.
+            iterator: If True directly return the underlying response
+                iterator
             action: Callable responsible of dealing with chunk of
                 data
             chunk_size: Size of each chunk
@@ -486,11 +505,13 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         """
         path = f"/projects/{self.encoded_id}/snapshot"
         result = self.manager.gitlab.http_get(
-            path, streamed=streamed, raw=True, **kwargs
+            path, streamed=streamed, raw=True, wiki=wiki, **kwargs
         )
         if TYPE_CHECKING:
             assert isinstance(result, requests.Response)
-        return utils.response_content(result, streamed, action, chunk_size)
+        return utils.response_content(
+            result, streamed, action, chunk_size, iterator=iterator
+        )
 
     @cli.register_custom_action("Project", ("scope", "search"))
     @exc.on_http_error(exc.GitlabSearchError)
@@ -574,7 +595,11 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             ),
             category=DeprecationWarning,
         )
-        return self.artifacts.raw(*args, **kwargs)
+        data = self.artifacts.raw(*args, **kwargs)
+        if TYPE_CHECKING:
+            assert data is not None
+            assert isinstance(data, bytes)
+        return data
 
 
 class ProjectManager(CRUDMixin, RESTManager):
@@ -1028,7 +1053,5 @@ class ProjectStorageManager(GetWithoutIdMixin, RESTManager):
     _obj_cls = ProjectStorage
     _from_parent_attrs = {"project_id": "id"}
 
-    def get(
-        self, id: Optional[Union[int, str]] = None, **kwargs: Any
-    ) -> Optional[ProjectStorage]:
-        return cast(Optional[ProjectStorage], super().get(id=id, **kwargs))
+    def get(self, **kwargs: Any) -> ProjectStorage:
+        return cast(ProjectStorage, super().get(**kwargs))
