@@ -1,6 +1,6 @@
-from typing import Any, cast, Optional, Union
+from typing import Any, cast
 
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     DeleteMixin,
@@ -9,6 +9,7 @@ from gitlab.mixins import (
     SaveMixin,
     UpdateMixin,
 )
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "ProjectPushRules",
@@ -51,7 +52,5 @@ class ProjectPushRulesManager(
         ),
     )
 
-    def get(
-        self, id: Optional[Union[int, str]] = None, **kwargs: Any
-    ) -> Optional[ProjectPushRules]:
-        return cast(Optional[ProjectPushRules], super().get(id=id, **kwargs))
+    def get(self, **kwargs: Any) -> ProjectPushRules:
+        return cast(ProjectPushRules, super().get(**kwargs))
